Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(888)

Unified Diff: remoting/host/constants.h

Issue 10873050: [Chromoting] Hook up host talkgadget policy checks. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove extra LOGs Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | remoting/host/constants.cc » ('j') | remoting/host/policy_hack/policy_watcher_linux.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/constants.h
diff --git a/remoting/host/constants.h b/remoting/host/constants.h
index 54aa2280c657a5ec1fdc210838a88f1c20071179..02f2f206f0fbe265646a8947dfa408bbf3b14f18 100644
--- a/remoting/host/constants.h
+++ b/remoting/host/constants.h
@@ -9,10 +9,13 @@
namespace remoting {
// This is the default prefix that is prepended to ".talkgadget.google.com"
// to form the complete talkgadget domain name. Policy settings allow admins
// to change the prefix that is used.
-extern const char kDefaultTalkGadgetPrefix[];
+extern const char kDefaultHostTalkGadgetPrefix[];
Sergey Ulanov 2012/08/24 19:43:33 We should avoid adding more values to this file (i
garykac 2012/08/27 22:34:57 I would rather merge constants_mac.cc and constant
Sergey Ulanov 2012/08/28 00:33:42 This has been discussed some time ago: https://chr
+
+// The base talkgadget URL.
+extern const char kTalkGadgetURL[];
Sergey Ulanov 2012/08/24 19:43:33 This should be kTalkGadgetUrl. From chromium code
garykac 2012/08/27 22:34:57 Done.
// Known host exit codes.
@@ -9,10 +9,13 @@
namespace remoting {
-// This is the default prefix that is prepended to ".talkgadget.google.com"
-// to form the complete talkgadget domain name. Policy settings allow admins
+// This is the default prefix that is prepended to the kTalkGadgetURL to form
+// the complete talkgadget URL used by the host. Policy settings allow admins
// to change the prefix that is used.
// Please keep this enum in sync with:
« no previous file with comments | « no previous file | remoting/host/constants.cc » ('j') | remoting/host/policy_hack/policy_watcher_linux.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698